==> kompare-16.12.0.tar.xz: kompare-16.12.0/libdialogpages/viewpage.h <==
/***************************************************************************
                                generalprefs.h
                                --------------
        begin                   : Sun Mar 4 2001
        Copyright 2001-2003 Otto Bruggeman <otto.bruggeman@home.nl>
        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
        Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
****************************************************************************/

/***************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
***************************************************************************/

#ifndef VIEWPAGE_H
#define VIEWPAGE_H

#include <QFrame>

#include "dialogpages_export.h"

class QFontComboBox;
class QSpinBox;
class QTabWidget;

class KColorButton;

class ViewSettings;

class DIALOGPAGES_EXPORT ViewPage : public QFrame
{
Q_OBJECT
public:
	ViewPage();
	~ViewPage();

public:
	void setSettings( ViewSettings* );
	ViewSettings* settings( void );

public:
	ViewSettings* m_settings;

public:
	virtual void restore();
	virtual void apply();
	virtual void setDefaults();

public:
	KColorButton* m_removedColorButton;
	KColorButton* m_changedColorButton;
	KColorButton* m_addedColorButton;
	KColorButton* m_appliedColorButton;
	// snol == scroll number of lines
	QSpinBox*     m_snolSpinBox;
	QSpinBox*     m_tabSpinBox;
	QFontComboBox*   m_fontCombo;
	QSpinBox*     m_fontSizeSpinBox;
	QTabWidget*   m_tabWidget;
};

#endif

==> kompare_17.12.3.orig.tar.xz: kompare-17.12.3/libdialogpages/viewpage.h <==
/***************************************************************************
                                generalprefs.h
                                --------------
        begin                   : Sun Mar 4 2001
        Copyright 2001-2003 Otto Bruggeman <otto.bruggeman@home.nl>
        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
        Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
****************************************************************************/

/***************************************************************************
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
***************************************************************************/

#ifndef VIEWPAGE_H
#define VIEWPAGE_H

#include <QFrame>

#include "dialogpages_export.h"

class QFontComboBox;
class QSpinBox;
class QTabWidget;

class KColorButton;

class ViewSettings;

class DIALOGPAGES_EXPORT ViewPage : public QFrame
{
    Q_OBJECT
public:
    ViewPage();
    ~ViewPage() override;

public:
    void setSettings(ViewSettings*);
    ViewSettings* settings();

public:
    ViewSettings* m_settings;

public:
    virtual void restore();
    virtual void apply();
    virtual void setDefaults();

public:
    KColorButton* m_removedColorButton;
    KColorButton* m_changedColorButton;
    KColorButton* m_addedColorButton;
    KColorButton* m_appliedColorButton;
    // snol == scroll number of lines
    QSpinBox*     m_snolSpinBox;
    QSpinBox*     m_tabSpinBox;
    QFontComboBox*   m_fontCombo;
    QSpinBox*     m_fontSizeSpinBox;
    QTabWidget*   m_tabWidget;
};

#endif
